function [domain] = geomsail(sail,domain)

n = sail.n;
m = sail.m;
span = sail.height;
sailchord = sail.chord;
NACA = sail.NACAS;

xg = domain.CG(1);
yg = domain.CG(2);
zg = domain.CG(3);

chord = abs(linspace(-max(sailchord),-min(sailchord),m+1));
[XP,ZP,~] = foilpoints(NACA,n+1);
XP = XP.*chord+domain.vel(1)*domain.dt*domain.k;
ZP = ZP.*chord;
YS = linspace(0,span,m+1)+1;
wlength = 400;
wlength2 = sail.vel(1)*sail.dt;
domain.case = 0;

B = transmatrix(90,180,180);

xp = XP;
ys = repmat(YS,n+1,1);
zp = ZP;
% Creating wake points
x2 = [xp(n+1,:); ones(1,m+1).*(xp(n+1)+wlength)];
y2 = [YS; YS];
z2 = [ones(1,m+1).*zp(n+1); ones(1,m+1).*zp(n+1)];
% Discretising the geometry of the sail
x = [xp(n+1,:); ones(1,m+1).*(xp(n+1)+wlength2)];
y = [YS; YS];
z = [ones(1,m+1).*zp(n+1); ones(1,m+1).*zp(n+1)];

% Finding control points.
for j = 1:m
    
    for k = 1:n
        
        if (j == m && k == n)
            
            P = [XP(k,j) YS(j) ZP(k,j); XP(k,j+1) YS(j+1) ZP(k,j+1);...
          XP(k+1,j+1) YS(j+1) ZP(k+1,j+1); XP(k+1,j) YS(j) ZP(k+1,j)];
      
            
        WW = [P(4,1) P(4,2) P(4,3); P(3,1) P(3,2) P(3,3);...
          wlength P(3,2) P(3,3); wlength P(4,2) P(4,3)];

      
        elseif j == m
            
          P = [XP(k,j) YS(j) ZP(k,j); XP(k,j+1) YS(j+1) ZP(k,j+1);...
          XP(k+1,j+1) YS(j+1) ZP(k+1,j+1); XP(k+1,j) YS(j) ZP(k+1,j)];
      
        elseif k == n
            
          P = [XP(k,j) YS(j) ZP(k,j); XP(k,j+1) YS(j+1) ZP(k,j+1);...
          XP(k+1,j+1) YS(j+1) ZP(k+1,j+1); XP(k+1,j) YS(j) ZP(k+1,j)];
   
        WW = [P(4,1) P(4,2) P(4,3); P(3,1) P(3,2) P(3,3);...
          wlength P(3,2) P(3,3); wlength P(4,2) P(4,3)];
 
        else
        
          P = [XP(k,j) YS(j) ZP(k,j); XP(k,j+1) YS(j+1) ZP(k,j+1);...
          XP(k+1,j+1) YS(j+1) ZP(k+1,j+1); XP(k+1,j) YS(j) ZP(k+1,j)];
      
        end
    
        % Rotating based on sail orientation
        
        [Px,Py,Pz] = rotgeom2(B,sail.pos,P(:,1),P(:,2),P(:,3),0,0,0);
    P = [Px Py Pz];

    domain.CP{k,j} = mean(P);
    domain.P{k,j} = P;
    [domain.N{k,j}, S(k,j)] = normalvec(P);
    
    end
    
    domain.W{j} = WW;

end

% Rotating sail based on orientation
[x2,y2,z2] = rotgeom2(B,sail.pos,x2,y2,z2,0,0,0);
[x,y,z] = rotgeom2(B,sail.pos,x,y,z,0,0,0);
[xp,ys,zp] = rotgeom2(B,sail.pos,xp,ys,zp,0,0,0);

domain.S = S;
domain.wake.x = x2;
domain.wake.y = y2;
domain.wake.z = z2;
domain.test.x = x;
domain.test.y = y;
domain.test.z = z;
domain.test2.x = xp;
domain.test2.y = ys;
domain.test2.z = zp;


end