function vel = inducedfast(CP,domain)
m = domain.mm;
n = domain.nn;

% This function calculates the induced velocity from a surface distribution
% of vortex rings at a point P. For references see the master thesis or
% Joseph Katz Low Speed Aerodynamics section 10.4.6
% The code requires a point P with (x,y,z) and 3 vectors which determine
% every single corner point of the vortex distribution across the surface
% n and m are number of elements in chord wise and span wise direction
% respectively.


x = domain.test2.x;
y = domain.test2.y;
z = domain.test2.z;
gamma = 1;
% Splitting the geometry into (i,j),(i+1,j),(i+1,j+1) and (i+1,j)
ax = x(1:1:end-1,1:1:end-1); ay = y(1:1:end-1,1:1:end-1); az = z(1:1:end-1,1:1:end-1);
bx = x(1:1:end-1,2:1:end); by = y(1:1:end-1,2:1:end); bz = z(1:1:end-1,2:1:end);
cx = x(2:1:end,2:1:end); cy = y(2:1:end,2:1:end); cz = z(2:1:end,2:1:end);
dx = x(2:1:end,1:1:end-1); dy = y(2:1:end,1:1:end-1); dz = z(2:1:end,1:1:end-1);

xa = [dx' ax' bx' cx']; xb = [ax' bx' cx' dx'];
ya = [dy' ay' by' cy']; yb = [ay' by' cy' dy'];
za = [dz' az' bz' cz']; zb = [az' bz' cz' dz'];
e = 1e-10;

xp = CP(1); yp = CP(2); zp = CP(3);

R1R2x2 = (yp-ya).*(zp-zb)-(zp-za).*(yp-yb);
R1R2y2 = -((xp-xa).*(zp-zb))+(zp-za).*(xp-xb);
R1R2z2 = (xp-xa).*(yp-yb)-(yp-ya).*(xp-xb);

R1R22 = R1R2x2.^2+R1R2y2.^2+R1R2z2.^2;
    
r12 = sqrt((xp-xa).^2+(yp-ya).^2+(zp-za).^2);
r22 = sqrt((xp-xb).^2+(yp-yb).^2+(zp-zb).^2);

r0r12 = (xb-xa).*(xp-xa)+(yb-ya).*(yp-ya)+(zb-za).*(zp-za);
r0r22 = (xb-xa).*(xp-xb)+(yb-ya).*(yp-yb)+(zb-za).*(zp-zb);
K2 = gamma.*((r0r12./r12)-(r0r22./r22))./(4.*pi.*R1R22);

u = K2.*R1R2x2;
v = K2.*R1R2y2;
w = K2.*R1R2z2;

% Removing singularities

u(isnan(u)) = 0;
v(isnan(v)) = 0;
w(isnan(w)) = 0;
cond = (find(R1R22 < e));
u(cond) = 0;
v(cond) = 0;
w(cond) = 0;
    
% Rearranging data for future use

tx = u(:); ty = v(:); tz = w(:);
tx2 = reshape(tx,n*m,[]); ty2 = reshape(ty,n*m,[]); tz2 = reshape(tz,n*m,[]);
tx3 = sum(tx2'); ty3 = sum(ty2'); tz3 = sum(tz2');

vel = [tx3' ty3' tz3'];

end