function hydro = liftmodel(foil,Vel,dt,k,hydro,amr,pos,simstart)

n = foil.n;
m = foil.m;
% Number of foils to be analysed
[gg,hh] = size(foil.span);

for j = 1:hh    
    
   Vel(3) = -Vel(3); 
   vel = Vel;
    
if k == 1
    
    domain.CG = pos.CG; % centre of gravity of the vessel
    domain.rot = hydro.rot; % vessel orientation
    domain.ang.phi = 90-foil.angle(j); % roll rotation of specific foil
    domain.ang.the = foil.angle2(j); % pitch rotation of specific foil
    domain.pos = amr.f(:,j); % centre of specific foil
    
    domain.span = foil.span(j); % Submerged span of specific foil
    domain.chord = foil.chord(j); % chord of specific foil
    domain.n = foil.n; % number of elements chordwise
    domain.k = k; % time step counter
    domain.m = foil.m; % number of elements spanwise
    domain.rho = 1025; % water density
    domain.NACA = cell2mat(foil.NACA(j)); % NACA profile for specific foil
    domain.dt = dt; % time step
    domain.vel = -vel; % Vessel velocity
    % Discretisising geometry
    domain = geomdisc(domain);
    % Saving wake grid
    domain.test.x2 = domain.test.x;
    domain.test.y2 = domain.test.y;
    domain.test.z2 = domain.test.z;
    % Initialising wake for the first time step.
    [dd,ff] = size(domain.test.x2);
    res.wake = ones(dd-1,ff-1).*0.5;
    res.k = k;
    % Unsteady Vortex Lattice Method simulator
    [res] = UVLM(Vel,domain,res);
    
    res.wake = res.circ(n,:);
    % If Wake roll up is preffered, the below is also used, however
    % diplacefast will also have to be used.
    
%     [domain,res] = wakerollupfast(domain,res);
    
else
    %     domain = diplacefast(domain,Vel);
    domain = hydro.domain(j);
    % Updating positions, lengths and orientations
    domain.CG = pos.CG;
    domain.rot = hydro.rot;
    domain.pos = amr.f(:,j);
    domain.k = k;
    domain.vel = -vel;
    domain.span = foil.span(j);
    % Discretisising geometry
    domain = geomdisc(domain);
    
    res = hydro.res(j);
    res.k = k+1;
    % Unsteady Vortex lattice Method simulator
    [res] = UVLM(Vel,domain,res);
    % Saving circulation of wake
    res.wake = [res.circ(n,:); res.wake];
    % Saving wake grid
    domain.test.x2 = [domain.test.x(1,:); domain.test.x2];
    domain.test.y2 = [domain.test.y(1,:); domain.test.y2];
    domain.test.z2 = [domain.test.z(1,:); domain.test.z2];
    % If Wake roll up is preffered, the below is also used, however
    % diplacefast will also have to be used.
%     [domain,res] = wakerollup(domain,res);
    
end
% Removing wake after a certain period.
cutoff = simstart;
if k > cutoff
    
    res.wake(cutoff-1:end,:) = [];
    domain.test.x2(cutoff:end,:) = [];
    domain.test.y2(cutoff:end,:) = [];
    domain.test.z2(cutoff:end,:) = [];
    
end

    hydro.domain(j) = domain;
    hydro.res(j) = res;

clear domain res

end

end
