function dydt = solveEOM(equil,Ig,CG,hull,etadot)
% This function solves the equation of motion.
m = hull.mass;

xg = CG(1); yg = CG(2); zg = CG(3); 

Ix = Ig(1,1); Ixy = Ig(1,2); Ixz = Ig(1,3);
Iy = Ig(2,2); Iyx = Ig(2,1); Iyz = Ig(2,3);
Iz = Ig(3,3); Izx = Ig(3,1); Izy = Ig(3,2);
% Mass matrix as described in property 3.1
M = [   m 0 0 0 m*zg -m*yg;...
        0 m 0 -m*zg 0 m*xg;...
        0 0 m m*yg -m*xg 0;...
        0 -m*zg m*yg Ix -Ixy -Ixz;...
        m*zg 0 -m*xg -Iyx Iy -Iyz;...
        -m*yg m*xg 0 -Izx -Izy Iz;];
% Centripetal matrix as described in Theorem 3.2
C = [   zeros(3,3)...
        -skew(M(1:3,1:3)*etadot(1:3)+M(1:3,4:6)*etadot(4:6));...
        -skew(M(1:3,1:3)*etadot(1:3)+M(1:3,4:6)*etadot(4:6))...
        -skew(M(4:6,1:3)*etadot(1:3)+M(4:6,4:6)*etadot(4:6))];
    
u = etadot(1); v = etadot(2); w = etadot(3);
p = etadot(4); q = etadot(5); r = etadot(6);
% The 6 Equilibrium states
Tau = [equil.Fx; equil.Fy; equil.Fz; equil.Mx; equil.My; equil.Mz];
% Adding added mass to the mass matrix
M = M+hull.Ma;

% dydt = M\(Tau-C*etadot);
dydt = M\Tau;
    
end